upgrades

package
v1.1.6-remove-onex Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 12, 2024 License: AGPL-3.0 Imports: 1 Imported by: 0

README

Onomy Upgrades

This folder contains sub-folders for every chain upgrade.

Version History

  • v1.1.4 - Add missing authz module
  • v1.1.2 - Fix that the treasury is actually subtracted from the staking supply
  • v1.1.1 - Removal of Gravity module and addition of provider module
  • v1.0.3.5 - OIP 6 Patch Subtract DAO Treasury from Staking Supply
  • v1.0.3.4 - OIP 6 Undelegate DAO from all validators
  • v1.0.3 - Hyperinflation fix
  • v1.0.1 - IBC integration fix

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Fork

type Fork struct {
	// Upgrade version name, for the upgrade handler, e.g. `v7`
	UpgradeName string
	// height the upgrade occurs at
	UpgradeHeight int64

	// Function that runs some custom state transition code at the beginning of a fork.
	BeginForkLogic func(ctx sdk.Context)
}

Fork defines a struct containing the requisite fields for a non-software upgrade proposal Hard Fork at a given height to implement. There is one time code that can be added for the start of the Fork, in `BeginForkLogic`. Any other change in the code should be height-gated, if the goal is to have old and new binaries to be compatible prior to the upgrade height.

Directories

Path Synopsis
Package v1_0_1 is contains chain upgrade of the corresponding version.
Package v1_0_1 is contains chain upgrade of the corresponding version.
Package v1_0_3 is contains chain upgrade of the corresponding version.
Package v1_0_3 is contains chain upgrade of the corresponding version.
Package v1_0_3_4 is contains chain upgrade of the corresponding version.
Package v1_0_3_4 is contains chain upgrade of the corresponding version.
Package v1_0_3_5 is contains chain upgrade of the corresponding version.
Package v1_0_3_5 is contains chain upgrade of the corresponding version.
Package v1_1_1 is contains chain upgrade of the corresponding version.
Package v1_1_1 is contains chain upgrade of the corresponding version.
Package v1_1_2 is contains chain upgrade of the corresponding version.
Package v1_1_2 is contains chain upgrade of the corresponding version.
Package v1_1_4 is contains chain upgrade of the corresponding version.
Package v1_1_4 is contains chain upgrade of the corresponding version.
Package v1_1_5 is contains chain upgrade of the corresponding version.
Package v1_1_5 is contains chain upgrade of the corresponding version.
Package v1_1_5 is contains chain upgrade of the corresponding version.
Package v1_1_5 is contains chain upgrade of the corresponding version.

Jump to