Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Fork ¶
type Fork struct {
// Upgrade version name, for the upgrade handler, e.g. `v7`
UpgradeName string
// height the upgrade occurs at
UpgradeHeight int64
// Function that runs some custom state transition code at the beginning of a fork.
BeginForkLogic func(ctx sdk.Context)
}
Fork defines a struct containing the requisite fields for a non-software upgrade proposal Hard Fork at a given height to implement. There is one time code that can be added for the start of the Fork, in `BeginForkLogic`. Any other change in the code should be height-gated, if the goal is to have old and new binaries to be compatible prior to the upgrade height.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package v1_0_1 is contains chain upgrade of the corresponding version.
|
Package v1_0_1 is contains chain upgrade of the corresponding version. |
|
Package v1_0_3 is contains chain upgrade of the corresponding version.
|
Package v1_0_3 is contains chain upgrade of the corresponding version. |
|
Package v1_0_3_4 is contains chain upgrade of the corresponding version.
|
Package v1_0_3_4 is contains chain upgrade of the corresponding version. |
|
Package v1_0_3_5 is contains chain upgrade of the corresponding version.
|
Package v1_0_3_5 is contains chain upgrade of the corresponding version. |
|
Package v1_1_1 is contains chain upgrade of the corresponding version.
|
Package v1_1_1 is contains chain upgrade of the corresponding version. |
|
Package v1_1_2 is contains chain upgrade of the corresponding version.
|
Package v1_1_2 is contains chain upgrade of the corresponding version. |
|
Package v1_1_4 is contains chain upgrade of the corresponding version.
|
Package v1_1_4 is contains chain upgrade of the corresponding version. |
|
Package v1_1_5 is contains chain upgrade of the corresponding version.
|
Package v1_1_5 is contains chain upgrade of the corresponding version. |
|
Package v1_1_5 is contains chain upgrade of the corresponding version.
|
Package v1_1_5 is contains chain upgrade of the corresponding version. |
Click to show internal directories.
Click to hide internal directories.